diff --git a/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/aio/operations_async/_share_operations_async.py b/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/aio/operations_async/_share_operations_async.py
index 915f757fc7c8..9834f1ed0b34 100644
--- a/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/aio/operations_async/_share_operations_async.py
+++ b/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/aio/operations_async/_share_operations_async.py
@@ -37,7 +37,7 @@ def __init__(self, client, config, serializer, deserializer) -> None:
self._config = config
self.restype = "share"
- async def create(self, timeout=None, metadata=None, quota=None, *, cls=None, **kwargs):
+ async def create(self, timeout=None, metadata=None, quota=None, access_tier=None, *, cls=None, **kwargs):
"""Creates a new share under the specified account. If the share with the
same name already exists, the operation fails.
@@ -51,6 +51,10 @@ async def create(self, timeout=None, metadata=None, quota=None, *, cls=None, **k
:type metadata: str
:param quota: Specifies the maximum size of the share, in gigabytes.
:type quota: int
+ :param access_tier: Specifies the access tier of the share. Possible
+ values include: 'TransactionOptimized', 'Hot', 'Cool'
+ :type access_tier: str or
+ ~azure.storage.fileshare.models.ShareAccessTier
:param callable cls: A custom type or function that will be passed the
direct response
:return: None or the result of cls(response)
@@ -78,6 +82,8 @@ async def create(self, timeout=None, metadata=None, quota=None, *, cls=None, **k
header_parameters['x-ms-meta'] = self._serialize.header("metadata", metadata, 'str')
if quota is not None:
header_parameters['x-ms-share-quota'] = self._serialize.header("quota", quota, 'int', minimum=1)
+ if access_tier is not None:
+ header_parameters['x-ms-access-tier'] = self._serialize.header("access_tier", access_tier, 'str')
header_parameters['x-ms-version'] = self._serialize.header("self._config.version", self._config.version, 'str')
# Construct and send request
@@ -176,6 +182,9 @@ async def get_properties(self, sharesnapshot=None, timeout=None, lease_access_co
'x-ms-lease-duration': self._deserialize(models.LeaseDurationType, response.headers.get('x-ms-lease-duration')),
'x-ms-lease-state': self._deserialize(models.LeaseStateType, response.headers.get('x-ms-lease-state')),
'x-ms-lease-status': self._deserialize(models.LeaseStatusType, response.headers.get('x-ms-lease-status')),
+ 'x-ms-access-tier': self._deserialize('str', response.headers.get('x-ms-access-tier')),
+ 'x-ms-access-tier-change-time': self._deserialize('rfc-1123', response.headers.get('x-ms-access-tier-change-time')),
+ 'x-ms-access-tier-transition-state': self._deserialize('str', response.headers.get('x-ms-access-tier-transition-state')),
'x-ms-error-code': self._deserialize('str', response.headers.get('x-ms-error-code')),
}
return cls(response, None, response_headers)
@@ -868,8 +877,8 @@ async def get_permission(self, file_permission_key, timeout=None, *, cls=None, *
return deserialized
get_permission.metadata = {'url': '/{shareName}'}
- async def set_quota(self, timeout=None, quota=None, lease_access_conditions=None, *, cls=None, **kwargs):
- """Sets quota for the specified share.
+ async def set_properties(self, timeout=None, quota=None, access_tier=None, lease_access_conditions=None, *, cls=None, **kwargs):
+ """Sets properties for the specified share.
:param timeout: The timeout parameter is expressed in seconds. For
more information, see None:
+ def __init__(self, *, last_modified, etag: str, quota: int, provisioned_iops: int=None, provisioned_ingress_mbps: int=None, provisioned_egress_mbps: int=None, next_allowed_quota_downgrade_time=None, deleted_time=None, remaining_retention_days: int=None, access_tier: str=None, access_tier_change_time=None, access_tier_transition_state: str=None, lease_status=None, lease_state=None, lease_duration=None, **kwargs) -> None:
super(ShareProperties, self).__init__(**kwargs)
self.last_modified = last_modified
self.etag = etag
@@ -817,6 +826,9 @@ def __init__(self, *, last_modified, etag: str, quota: int, provisioned_iops: in
self.next_allowed_quota_downgrade_time = next_allowed_quota_downgrade_time
self.deleted_time = deleted_time
self.remaining_retention_days = remaining_retention_days
+ self.access_tier = access_tier
+ self.access_tier_change_time = access_tier_change_time
+ self.access_tier_transition_state = access_tier_transition_state
self.lease_status = lease_status
self.lease_state = lease_state
self.lease_duration = lease_duration
diff --git a/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/operations/_share_operations.py b/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/operations/_share_operations.py
index 5e1bbb6325e8..3e26c16a451f 100644
--- a/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/operations/_share_operations.py
+++ b/sdk/storage/azure-storage-file-share/azure/storage/fileshare/_generated/operations/_share_operations.py
@@ -37,7 +37,7 @@ def __init__(self, client, config, serializer, deserializer):
self._config = config
self.restype = "share"
- def create(self, timeout=None, metadata=None, quota=None, cls=None, **kwargs):
+ def create(self, timeout=None, metadata=None, quota=None, access_tier=None, cls=None, **kwargs):
"""Creates a new share under the specified account. If the share with the
same name already exists, the operation fails.
@@ -51,6 +51,10 @@ def create(self, timeout=None, metadata=None, quota=None, cls=None, **kwargs):
:type metadata: str
:param quota: Specifies the maximum size of the share, in gigabytes.
:type quota: int
+ :param access_tier: Specifies the access tier of the share. Possible
+ values include: 'TransactionOptimized', 'Hot', 'Cool'
+ :type access_tier: str or
+ ~azure.storage.fileshare.models.ShareAccessTier
:param callable cls: A custom type or function that will be passed the
direct response
:return: None or the result of cls(response)
@@ -78,6 +82,8 @@ def create(self, timeout=None, metadata=None, quota=None, cls=None, **kwargs):
header_parameters['x-ms-meta'] = self._serialize.header("metadata", metadata, 'str')
if quota is not None:
header_parameters['x-ms-share-quota'] = self._serialize.header("quota", quota, 'int', minimum=1)
+ if access_tier is not None:
+ header_parameters['x-ms-access-tier'] = self._serialize.header("access_tier", access_tier, 'str')
header_parameters['x-ms-version'] = self._serialize.header("self._config.version", self._config.version, 'str')
# Construct and send request
@@ -176,6 +182,9 @@ def get_properties(self, sharesnapshot=None, timeout=None, lease_access_conditio
'x-ms-lease-duration': self._deserialize(models.LeaseDurationType, response.headers.get('x-ms-lease-duration')),
'x-ms-lease-state': self._deserialize(models.LeaseStateType, response.headers.get('x-ms-lease-state')),
'x-ms-lease-status': self._deserialize(models.LeaseStatusType, response.headers.get('x-ms-lease-status')),
+ 'x-ms-access-tier': self._deserialize('str', response.headers.get('x-ms-access-tier')),
+ 'x-ms-access-tier-change-time': self._deserialize('rfc-1123', response.headers.get('x-ms-access-tier-change-time')),
+ 'x-ms-access-tier-transition-state': self._deserialize('str', response.headers.get('x-ms-access-tier-transition-state')),
'x-ms-error-code': self._deserialize('str', response.headers.get('x-ms-error-code')),
}
return cls(response, None, response_headers)
@@ -868,8 +877,8 @@ def get_permission(self, file_permission_key, timeout=None, cls=None, **kwargs):
return deserialized
get_permission.metadata = {'url': '/{shareName}'}
- def set_quota(self, timeout=None, quota=None, lease_access_conditions=None, cls=None, **kwargs):
- """Sets quota for the specified share.
+ def set_properties(self, timeout=None, quota=None, access_tier=None, lease_access_conditions=None, cls=None, **kwargs):
+ """Sets properties for the specified share.
:param timeout: The timeout parameter is expressed in seconds. For
more information, see